@@ -21,12 +21,12 @@ BlogfeedWidget::BlogfeedWidget(QWidget *parent)
     auto topLayout = new QVBoxLayout(this);
     topLayout->setContentsMargins({});
     topLayout->setObjectName(QLatin1StringView("mainlayout"));
-    auto blogFeedLabel = new QLabel(i18n("Blog Feed"), this);
+    auto blogFeedLabel = new QLabel(i18nc("@label:textbox", "Blog Feed"), this);
     blogFeedLabel->setObjectName(QLatin1StringView("blogFeedLabel"));
     topLayout->addWidget(blogFeedLabel);
 
     mBlogFeed->setTrapReturnKey(true);
-    mBlogFeed->setPlaceholderText(i18n("Add a Blog Feed"));
+    mBlogFeed->setPlaceholderText(i18nc("@info:placeholder", "Add a Blog Feed"));
     mBlogFeed->setObjectName(QLatin1StringView("blogfeed"));
     topLayout->addWidget(mBlogFeed);
 }
