@@ -23,7 +23,7 @@ MailListWidget::MailListWidget(QWidget *parent)
     topLayout->setContentsMargins({});
     topLayout->setSpacing(0);
 
-    auto label = new QLabel(i18n("Email"), this);
+    auto label = new QLabel(i18nc("@label:textbox", "Email"), this);
     label->setObjectName(QLatin1StringView("emaillistlabel"));
     topLayout->addWidget(label);
 
