@@ -22,12 +22,12 @@ NicknameWidget::NicknameWidget(QWidget *parent)
     auto topLayout = new QVBoxLayout(this);
     topLayout->setContentsMargins({});
     topLayout->setObjectName(QLatin1StringView("mainlayout"));
-    auto nickNameLabel = new QLabel(i18n("Nickname"), this);
+    auto nickNameLabel = new QLabel(i18nc("@label:textbox", "Nickname"), this);
     nickNameLabel->setObjectName(QLatin1StringView("nicknamelabel"));
     topLayout->addWidget(nickNameLabel);
 
     mNickName->setTrapReturnKey(true);
-    mNickName->setPlaceholderText(i18n("Add a Nickname"));
+    mNickName->setPlaceholderText(i18nc("@info:placeholder", "Add a Nickname"));
     mNickName->setObjectName(QLatin1StringView("nickname"));
     topLayout->addWidget(mNickName);
 }
